@@ -66,13 +66,13 @@ namespace internal {
 //  take up almost half the memory of this representation, so if memory does
 //  become a concern, we do not need to store them.  The only reason we do so now
 //  is that the face-value interface for specifying base topology and inspecting
-//  subsequent levels is very familar to that of face-vertices for clients.  So
+//  subsequent levels is very familiar to that of face-vertices for clients.  So
 //  having them available for such access is convenient.
 //
 //  Regarding scope and access...
 //      Unclear at this early state, but leaning towards nesting this class within
 //  Level, given the intimate dependency between the two.
-//      Everything is being declared public for now to facilitate access until its
+//      Everything is being declared public for now to facilitate access until it's
 //  clearer how this functionality will be provided.
 //
 class FVarLevel {
@@ -135,6 +135,16 @@ public:
         ValueTagSize _infIrregular  : 1;  // value span includes inf-sharp irregularity
 
         Level::VTag combineWithLevelVTag(Level::VTag) const;
+
+        //  Alternate constructor and accessor for dealing with integer bits directly:
+        explicit ValueTag(ValueTagSize bits) {
+            std::memcpy(this, &bits, sizeof(bits));
+        }
+        ValueTagSize getBits() const {
+            ValueTagSize bits;
+            std::memcpy(&bits, this, sizeof(bits));
+            return bits;
+        }
     };
 
     typedef Vtr::ConstArray<ValueTag> ConstValueTagArray;
@@ -387,23 +397,34 @@ inline Level::VTag
 FVarLevel::ValueTag::combineWithLevelVTag(Level::VTag levelTag) const
 {
     if (this->_mismatch) {
+        //
+        //  Semi-sharp FVar values are always tagged and treated as corners
+        //  (at least three sharp edges (two boundary edges and one interior
+        //  semi-sharp) and/or vertex is semi-sharp) until the sharpness has
+        //  decayed, but they ultimately lie on the inf-sharp crease of the
+        //  FVar boundary.  Consider this when tagging inf-sharp features.
+        //
         if (this->isCorner()) {
             levelTag._rule = (Level::VTag::VTagSize) Sdc::Crease::RULE_CORNER;
-            levelTag._infSharp = true;
-            levelTag._infSharpCrease = false;
-            levelTag._corner = !this->_infIrregular && !this->_infSharpEdges;
         } else {
             levelTag._rule = (Level::VTag::VTagSize) Sdc::Crease::RULE_CREASE;
+        }
+        if (this->isCrease() || this->isSemiSharp()) {
             levelTag._infSharp = false;
             levelTag._infSharpCrease = true;
             levelTag._corner = false;
+        } else {
+            levelTag._infSharp = true;
+            levelTag._infSharpCrease = false;
+            levelTag._corner = !this->_infIrregular && !this->_infSharpEdges;
         }
         levelTag._infSharpEdges = true;
         levelTag._infIrregular = this->_infIrregular;
 
         levelTag._boundary = true;
         levelTag._xordinary = this->_xordinary;
-        levelTag._nonManifold = this->_nonManifold;
+
+        levelTag._nonManifold |= this->_nonManifold;
     }
     return levelTag;
 }
